@@ -47,7 +47,7 @@ from data_science_helper.model import lgb_model as l
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,enable_cls_opt = False, enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
+def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,max_iter_cls=None, cls_ini_opt=[] ,enable_cls_opt = False, enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
     start = time.time()
         
     params.update({"metric":metric})
@@ -58,10 +58,12 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state,"api":api ,"strategy":strategy,
             "url":url }     
     
+    list_cls_ini = None
     
     if (enable_cls_opt):
     
-        list_cls_ini = ['Z_NOTA_M_T_MENOS_1', 'Z_NOTA_C_T_MENOS_1', 'EXTRA_EDAD_T_MENOS_1']+hd.get_bool_columns(X_train)
+        #list_cls_ini = ['Z_NOTA_M_T_MENOS_1', 'Z_NOTA_C_T_MENOS_1', 'EXTRA_EDAD_T_MENOS_1']+hd.get_bool_columns(X_train)
+        list_cls_ini = cls_ini_opt + hd.get_bool_columns(X_train)
         
         list_cls = hd.Diff(X_train.columns.tolist(),list_cls_ini) 
         
@@ -71,8 +73,10 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
         
         for COLUMN in list_cls:
             
-            if len(list_sesgo)>5:
-                break
+            if max_iter_cls is not None:
+            
+                if len(list_sesgo)>=max_iter_cls:
+                    break
             
             list_cls_ini.append(COLUMN)
             
@@ -124,6 +128,8 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
         args["X_train"]=X_train[list_cls_ini]
         args["X_test"]=X_test[list_cls_ini]
         args["url"]=url
+        
+
    
     model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
     
@@ -137,7 +143,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
     
     print("Time elapsed: ", time.time() - start)
     
-    return model ,  kpis_train, kpis_test , kpis_opt , umbral_opt
+    return model ,  kpis_train, kpis_test , kpis_opt , umbral_opt , list_cls_ini
 
 
 def modelar_clasificacion_binaria_rscv(strategy, X_train,y_train=None,X_test=None,y_test=None,score_rs=None,params=None,param_dist=None, n_iter=None,n_jobs=None,url=None,print_consola=True):
